<?php

function kanary_options_panel_init()
{
	$options_panel = new Kanary_Options();
	global $theme_settings;

	$theme_settings = $options_panel->get_options();
}

add_action('init', 'kanary_options_panel_init', 0);
add_action('customize_preview_init', 'kanary_options_panel_init');

require_once 'options-framework.php';

/**
 * Returns an array of system fonts
 * Feel free to edit this, update the font fallbacks, etc.
 */
function kanary_supported_os_fonts()
{
	// OS Font Defaults
	$os_faces = array(
		'Arial, sans-serif'                                       => 'Arial',
		"'Avant Garde', sans-serif"                               => 'Avant Garde',
		'Cambria, Georgia, serif'                                 => 'Cambria',
		'Copse, sans-serif'                                       => 'Copse',
		"Garamond, 'Hoefler Text', Times New Roman, Times, serif" => 'Garamond',
		'Georgia, serif'                                          => 'Georgia',
		"'Helvetica Neue', Helvetica, sans-serif"                 => 'Helvetica Neue',
		'Tahoma, Geneva, sans-serif'                              => 'Tahoma'
	);

	return $os_faces;
}

/**
 * Returns a select list of Google fonts
 * Feel free to edit this, update the fallbacks, etc.
 */

function kanary_supported_google_fonts()
{
	// Google Font Defaults
	$google_faces = array(
		'Arvo, serif'                     => 'Arvo (Google)',
		'Copse, sans-serif'               => 'Copse (Google)',
		'Droid Sans, sans-serif'          => 'Droid Sans (Google)',
		'Droid Serif, serif'              => 'Droid Serif (Google)',
		'Lobster, cursive'                => 'Lobster (Google)',
		'Nobile, sans-serif'              => 'Nobile (Google)',
		'Open Sans, sans-serif'           => 'Open Sans (Google)',
		'Oswald, sans-serif'              => 'Oswald (Google)',
		'Pacifico, cursive'               => 'Pacifico (Google)',
		'Rokkitt, serif'                  => 'Rokkit (Google)',
		'PT Sans, sans-serif'             => 'PT Sans (Google)',
		'Quattrocento, serif'             => 'Quattrocento (Google)',
		'Raleway, cursive'                => 'Raleway (Google)',
		'Ubuntu, sans-serif'              => 'Ubuntu (Google)',
		'Yanone Kaffeesatz, sans-serif'   => 'Yanone Kaffeesatz (Google)',
		'Bree Serif, serif'               => 'Bree Serif (Google)',
		'Poiret One, cursive'             => 'Poiret One (Google)',
		'PT Serif, serif'                 => 'PT Serif (Google)',
		'Titillium Web, sans-serif'       => 'Titillium Web (Google)',
		'Merriweather, serif'             => 'Merriweather (Google)',
		'Roboto, sans-serif'              => 'Roboto (Google)',
		'Roboto Slab, serif'              => 'Roboto Slab (Google)',
		'Open Sans Condensed, sans-serif' => 'Open Sans Condensed (Google)'
	);
	return $google_faces;
}

class Kanary_Options extends Kanary_Options_Framework
{

	function __construct()
	{
		parent::__construct($this->get_option_id());
	}

	/**
	 * @return mixed|string|void
	 */
	public static function get_option_id()
	{
		$option_id = "kanary_theme_options";
		$option_id = apply_filters('kanary_option_id', $option_id);
		return $option_id;
	}

	protected function get_setting_sections()
	{
		$settings_sections = array(
			'general' => __('Kanary General', 'limelight'),
			'home'    => __('Kanary Homepage', 'limelight'),
			'slider'  => __('Kanary Slider', 'limelight'),
			'layouts' => __('Kanary Layout', 'limelight'),
			'styling' => __('Kanary Styling', 'limelight'),
			'fonts'   => __('Kanary Fonts', 'limelight'),
			'social'  => __('Kanary Social', 'limelight'),
			'footer'  => __('Kanary Footer', 'limelight')
		);

		return apply_filters('kanary_setting_sections', $settings_sections);
	}

	protected function get_setting_fields()
	{

		$fonts = array_merge(kanary_supported_os_fonts(), kanary_supported_google_fonts());
		asort($fonts);
		$fonts = array_merge(array('' => 'Inherit'), $fonts);

		$layouts = array(
			''                => __('Inherit', 'limelight'),
			'content-sidebar' => __('Right Sidebar', 'limelight'),
			'sidebar-content' => __('Left Sidebar', 'limelight'),
			'fullwidth'       => __('Fullwidth', 'limelight')
		);

		$setting_fields = array(
			'general' => array(
				'custom_favicon' => array(
					'label' => __('Favicon', 'limelight'),
					'type'  => 'media_url'
				),

				'logo' => array(
					'label' => __('Logo URL', 'limelight'),
					'type'  => 'media_url'
				),

				'responsive_tables' => array(
					'label'   => __('Make HTML tables responsive', 'limelight'),
					'type'    => 'checkbox',
					'default' => false
				)
			),

			'layouts' => array(
				'sidebar_width' => array(
					'label'   => __('Sidebar Width', 'limelight'),
					'type'    => 'select',
					'choices' => array(
						''            => '250px',
						'sidebar-300' => '300px',
						'sidebar-350' => '350px',
						'sidebar-400' => '400px'
					)
				),

				'general' => array(
					'label'   => __('Layout', 'limelight'),
					'type'    => 'select',
					'choices' => $layouts
				),

				'single' => array(
					'label'   => __('Single Layout', 'limelight'),
					'type'    => 'select',
					'choices' => $layouts
				),

				'single_post' => array(
					'label'   => __('Single Post Layout', 'limelight'),
					'type'    => 'select',
					'choices' => $layouts
				),

				'single_page' => array(
					'label'   => __('Single Page Layout', 'limelight'),
					'type'    => 'select',
					'choices' => $layouts
				),

				'archive' => array(
					'label'   => __('Archive Layout', 'limelight'),
					'type'    => 'select',
					'choices' => $layouts
				),

				'archive_category' => array(
					'label'   => __('Category Archive Layout', 'limelight'),
					'type'    => 'select',
					'choices' => $layouts
				),

				'archive_tag' => array(
					'label'   => __('Tag Archive Layout', 'limelight'),
					'type'    => 'select',
					'choices' => $layouts
				)
			),

			'home' => array(
				'show_excerpts' => array(
					'label' => __('Show Excerpts', 'limelight'),
					'type'  => 'checkbox'
				),
			),

			'slider' => array(
				'disable_slider' => array(
					'label' => __('Disable slider?', 'limelight'),
					'type'  => 'checkbox'
				),

				'slides' => array(
					'label' => __('Slider Images', 'limelight'),
					'type'  => 'media_items'
				),

				'transitionStyle' => array(
					'label'   => __('Transition Style', 'limelight'),
					'type'    => 'select',
					'choices' => array('' => __('Slide', 'limelight'), 'fade' => __('Fade', 'limelight'), 'backSlide' => __('Back Slide', 'limelight'), 'goDown' => __('Go Down', 'limelight'), 'fadeUp' => __('Fade Up', 'limelight')),
				),

				'pagination' => array(
					'label'   => __('Display Pagination', 'limelight'),
					'type'    => 'checkbox',
					'default' => true
				),

				'autoPlay' => array(
					'label'   => __('Auto Play', 'limelight'),
					'type'    => 'checkbox',
					'default' => false
				),

				'stopOnHover' => array(
					'label'   => __('Stop On Hover', 'limelight'),
					'type'    => 'checkbox',
					'default' => false
				),

				'navigation' => array(
					'label'   => __('Display Navigation', 'limelight'),
					'type'    => 'checkbox',
					'default' => false
				)
			),

			'styling' => array(
				'bg_color' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'body{background-color:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label' => __('Background Color', 'limelight'),
							'type'  => 'color'
						)
					)
				),

				'bg_img' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'body{background-image:url(%s);}',
							'customizer' => false
						),
						'value'  => array(
							'label' => __('Background Image', 'limelight'),
							'type'  => 'media_url'
						)
					)
				),

				'bg_repeat' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'body{background-repeat:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label'   => __('Background Repeat', 'limelight'),
							'type'    => 'select',
							'choices' => array('repeat' => __('Horizontally & vertically', 'limelight'), 'repeat-x' => __('Horizontally', 'limelight'), 'repeat-y' => __('Vertically', 'limelight'))
						)
					)
				),

				'a_color' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'a{color:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label' => __('Link Color', 'limelight'),
							'type'  => 'color'
						)
					)
				),

				'a_visited_color' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'a:visited{color:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label' => __('Link Visited Color', 'limelight'),
							'type'  => 'color'
						)
					)
				),

				'a_hover_color' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'a:hover{color:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label' => __('Link Hover Color', 'limelight'),
							'type'  => 'color'
						)
					)
				),

				'entry_title_a_color' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => '.entry-title a{color:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label' => __('Entry Title Link Color', 'limelight'),
							'type'  => 'color'
						)
					)
				),

				'entry_title_a_visited_color' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => '.entry-title a:visited{color:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label' => __('Entry Title Link Visited Color', 'limelight'),
							'type'  => 'color'
						)
					)
				),

				'entry_title_a_hover_color' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => '.entry-title a:hover{color:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label' => __('Entry Title Link Hover Color', 'limelight'),
							'type'  => 'color'
						)
					)
				)

			),

			'fonts' => array(
				'font_size' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'body, button, input, select, textarea{font-size:%spx;}',
							'customizer' => false
						),
						'value'  => array(
							'label'   => __('Font Size', 'limelight'),
							'type'    => 'number',
							'default' => 16
						)
					)
				),

				'font_family' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'body, button, input, select, textarea{font-family:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label'   => __('Basic Font', 'limelight'),
							'type'    => 'select',
							'choices' => $fonts
						)
					)
				),

				'headings_font_family' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'h1,h2,h3,h4,h5,h6{font-family:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label'   => __('Headings Font', 'limelight'),
							'type'    => 'select',
							'choices' => $fonts
						)
					)
				),

				'site_title_font_family' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => '.site-title{font-family:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label'   => __('Site Title Font', 'limelight'),
							'type'    => 'select',
							'choices' => $fonts
						)
					)
				),

				'post_title_font_family' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => '.entry-title{font-family:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label'   => __('Post Title Font', 'limelight'),
							'type'    => 'select',
							'choices' => $fonts
						)
					)
				),

				'widget_title_font_family' => array(
					'type'  => 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => '.widget-title{font-family:%s;}',
							'customizer' => false
						),
						'value'  => array(
							'label'   => __('Widget Title Font', 'limelight'),
							'type'    => 'select',
							'choices' => $fonts
						)
					)
				),
			),

			'social' => array(
				'twitter' => array(
					'label' => __('Twitter URL', 'limelight'),
					'type'  => 'url'
				),

				'fb' => array(
					'label' => __('Facebook URL', 'limelight'),
					'type'  => 'url'
				),

				'google_plus' => array(
					'label' => __('Google Plus URL', 'limelight'),
					'type'  => 'url'
				),

				'instagram' => array(
					'label' => __('Instagram URL', 'limelight'),
					'type'  => 'url'
				),

				'pinterest' => array(
					'label' => __('Pinterest URL', 'limelight'),
					'type'  => 'url'
				),

				'youtube' => array(
					'label' => __('Youtube URL', 'limelight'),
					'type'  => 'url'
				),

				'feedburner' => array(
					'label' => __('Feedburner URL', 'limelight'),
					'type'  => 'url'
				)
			),

			'footer' => array(
				'columns' => array(
					'label'   => __('Columns', 'limelight'),
					'type'    => 'select',
					'choices' => array(
						'3' => '3',
						'2' => '2',
						'1' => '1'
					),
					'default' => '3'
				),

				'footer_text' => array(
					'label'   => __('Footer Copyright Text', 'limelight'),
					'type'    => 'text',
					'default' => '&copy; ' . get_bloginfo('name')
				),

				'hide_credits' => array(
					'label' => __('Hide credit link?', 'limelight'),
					'type'  => 'checkbox'
				)
			)
		);

		return apply_filters('kanary_setting_fields', $setting_fields);
	}
}