<?php

function limelight_font_style()
{
	global $theme_settings;

	if (!$theme_settings['fonts']['font_family']['value']) {
		// We need to enqueue a font that will be used throughout the site. If the user has already chosen one that can replace this then there is no need to enqueue it.
		wp_enqueue_style("open-sans", "http://fonts.googleapis.com/css?family=Open+Sans:400,300", null, "1.0", "all");
	}

	if (!$theme_settings['fonts']['site_title_font_family']['value']) {
		wp_enqueue_style("limelight-lobster", "https://fonts.googleapis.com/css?family=Lobster", null, "1.0", "all");
	}
}

add_action('wp_enqueue_scripts', 'limelight_font_style');

function limelight_remove_skin_from_printed_styles($styles)
{
	unset($styles['skin']);

	return $styles;
}

add_filter('kanary_customization_css_styles', 'limelight_remove_skin_from_printed_styles');

function limelight_skin_body_class($classes)
{
	global $theme_settings;

	// Add the skin class.
	if ($theme_settings['styling']['skin']) {
		$classes[] = sanitize_html_class($theme_settings['styling']['skin']);
	}

	return $classes;
}

add_filter('body_class', 'limelight_skin_body_class');

function limelight_add_skin_option($fields)
{
	$skins = array(
		''              => __('Sea Green', 'limelight'),
		'asbestos'      => __('Asbestos', 'limelight'),
		'belize-blue'   => __('Belize Blue', 'limelight'),
		'dark'          => __('Dark', 'limelight'),
		'midnight-blue' => __('Midnight Blue', 'limelight'),
		'orange'        => __('Orange', 'limelight'),
		'pomegranate'   => __('Pomegranate', 'limelight'),
		'pumpkin'       => __('Pumpkin', 'limelight'),
		'wisteria'      => __('Wisteria', 'limelight')
	);

	$fields['styling'] = array(
		'skin' => array(
			'label'   => __('Skin', 'limelight'),
			'type'    => 'select',
			'choices' => $skins
		)
	);

	return $fields;
}

add_filter('kanary_setting_fields', 'limelight_add_skin_option');

function limelight_change_customizer_titles($translated_text, $text)
{
	if ($translated_text != $text || strpos($text, 'Kanary') === false) {
		return $translated_text;
	}

	return str_replace('Kanary', 'Limelight', $text);
}

add_filter('gettext', 'limelight_change_customizer_titles', 20, 2);

function limelight_update_credit_theme_urls($theme_urls)
{
	return str_replace('kanary', 'limelight-theme', $theme_urls);
}

add_filter('kanary_credit_theme_urls', 'limelight_update_credit_theme_urls');

function limelight_change_option_id()
{
	return 'limelight_theme_options';
}

add_filter('kanary_option_id', 'limelight_change_option_id');